@@ -11,7 +11,9 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import logging
 from chi_edge.ansible import cli
 
+logging.basicConfig(level=logging.INFO)
+
 cli()
